@@ -68,9 +68,9 @@ ox_set_JAVA_BIN() {
             JAVA_BIN=$jb
         fi
     fi
-    test -x $JAVA_BIN || die "$0: unable to get path to java vm"
+    test -x "$JAVA_BIN" || die "$0: unable to get path to java vm"
     version=$(detect_java_version)
-    if [ $version -lt 7 ]; then
+    if [ $version -lt 8 ]; then
       JAVA_BIN=/opt/open-xchange/sbin/insufficientjava
     fi
 }
@@ -222,6 +222,47 @@ ox_daemon_status() {
     fi
 }
 
+# Scans for expression 1 in the file given as parameter2
+#
+# Param1: The expression to look for
+# Param2: The file to search in
+# Return: 0 if the expression was found, 1 otherwise
+# Example:
+#
+#   root@host:~$ $(contains SERVER_NAME /opt/open-xchange/etc/system.properties)
+#   && echo yes || echo no
+#   yes
+#   root@host:~$ 
+#
+contains() {
+    local expression="$1"
+    local file="$2"
+    test -z "$expression" && die "contains: missing expression argument (arg 1)"
+    test -z "$file" && die "contains: missing file argument (arg 2)"
+    test -e "$file" || die "contains: $file does not exist"
+
+    grep -q -- "$expression" "$file"
+    return $?
+}
+
+# Calculate and return only the md5sum of the given file
+# Param1: The (prop)file to calculate the md5sum from
+# Return: The md5 sum of the file given as Param1 
+# Example:
+#
+#   root@host:~$ [[ $(ox_md5 /usr/bin/md5sum) = $(ox_md5 /usr/bin/md5sum) ]] && echo equal || echo differ
+#   equal
+#   root@host:~$ 
+#
+function ox_md5() {
+    local file="$1"
+    test -z "$file" && die "ox_md5: missing file argument (arg 1)"
+    test -e "$file" || die "ox_md5: $file does not exist"
+    local output=$(md5sum $file)
+    local md5=${output%% *}
+    echo $md5
+}
+
 # usage:
 # ox_set_property property value /path/to/file
 #
@@ -348,7 +389,11 @@ if ( $found ) {
             rm -f $tmp
             die "ox_set_property: FATAL: error setting property $prop to \"$val\" in $propfile"
         else
-            mv $tmp $propfile
+            if [[ $(ox_md5 $tmp) != $(ox_md5 $propfile) ]]; then
+              mv $tmp $propfile
+            else
+              rm $tmp
+            fi
         fi
         unset origfile
         unset propfile
@@ -370,7 +415,11 @@ EOF
             rm -f $tmp
             die "ox_set_property: FATAL: error setting property $prop to \"$val\" in $propfile"
         else
-            mv $tmp $propfile
+            if [[ $(ox_md5 $tmp) != $(ox_md5 $propfile) ]]; then
+              mv $tmp $propfile
+            else
+              rm $tmp
+            fi
         fi
     fi
 }
@@ -449,12 +498,13 @@ ox_remove_property() {
     test -z "$propfile" && die "ox_remove_property: missing propfile argument (arg 2)"
     test -e "$propfile" || die "ox_remove_property: $propfile does not exist"
 
-    local tmp=${propfile}.tmp$$
-    cp -a --remove-destination $propfile $tmp
+    if ox_exists_property "$prop" "$propfile"; then
+        local tmp=${propfile}.tmp$$
+        cp -a --remove-destination $propfile $tmp
 
-    export propfile
-    export prop
-    perl -e '
+        export propfile
+        export prop
+        perl -e '
 use strict;
 
 open(IN,"$ENV{propfile}") || die "unable to open $ENV{propfile}: $!";
@@ -484,11 +534,12 @@ for (my $i=0; $i<=$#LINES; $i++) {
     }
 }
 ' > $tmp
-    if [ $? -gt 0 ]; then
-        rm -f $tmp
-        die "ox_remove_property: FATAL: error removing property $prop from $propfile"
-    else
-        mv $tmp $propfile
+        if [ $? -gt 0 ]; then
+            rm -f $tmp
+            die "ox_remove_property: FATAL: error removing property $prop from $propfile"
+        else
+            mv $tmp $propfile
+        fi
     fi
     unset propfile
     unset prop
@@ -751,12 +802,12 @@ ox_set_max_heap() {
       break
     fi
   done
-  
+
   ((modified)) || return 1
 
   # quote
   new_opts_line=\"${opts[*]}\"
-  
+
   # persist
   if ((new_style))
   then
@@ -766,3 +817,4 @@ ox_set_max_heap() {
   fi
   return $?
 }
+
